@@ -41,7 +41,7 @@ GOOD_WORDS = ['back', 'bad', 'badge', 'bag', 'ball', 'bar', 'bare', 'base', 'bas
                  'jet', 'job', 'jog', 'join', 'joke', 'judge', 'june', 'keep', 'kick', 'kid', 'kill', 'king', 'kiss', 'knife', 'knit', 'knob', 'knock',
                  'known', 'lack', 'lag', 'laid', 'lake', 'lame', 'lane', 'lash', 'latch', 'late', 'laugh', 'lawn', 'league', 'leak', 'lean', 'learn',
                  'lease', 'leash', 'leave', 'led', 'leg', 'let', 'lid', 'life', 'light', 'line', 'load', 'loan', 'lock', 'lodge', 'lone', 'long', 'look',
-                 'loose', 'lose', 'loss', 'loud', 'love', 'loyal', 'luck', 'mad', 'made', 'maid', 'mail', 'main', 'make', 'male', 'mall',
+                 'loose', 'lose', 'loss', 'loud', 'love', 'luck', 'mad', 'made', 'maid', 'mail', 'main', 'make', 'male', 'mall',
                  'map', 'mass', 'mat', 'match', 'math', 'meal', 'meat', 'meet', 'men', 'mess', 'met', 'mid', 'mike', 'mile', 'mill',
                  'miss', 'mock', 'moon', 'mouth', 'move', 'mud', 'nail', 'name', 'nap', 'neat', 'neck', 'need', 'nerve', 'net', 'news',
                  'nice', 'niche', 'niece', 'night', 'noise', 'noon', 'nose', 'notch', 'note', 'noun', 'nurse', 'nut', 'pace', 'pack', 'page',
@@ -54,7 +54,7 @@ GOOD_WORDS = ['back', 'bad', 'badge', 'bag', 'ball', 'bar', 'bare', 'base', 'bas
                  'shell', 'ship', 'shirt', 'shock', 'shoot', 'shop', 'shot', 'shown', 'shun', 'shut', 'sick', 'side', 'sight', 'sign', 'sin', 'sing',
                  'sit', 'site', 'size', 'soap', 'son', 'song', 'soon', 'soul', 'soup', 'south', 'suit', 'sung', 'tab', 'tag', 'tail', 'take', 'talk',
                  'tap', 'tape', 'taught', 'teach', 'team', 'tease', 'teeth', 'tell', 'term', 'theme', 'thick', 'thief', 'thing', 'thought', 'tiff',
-                 'tight', 'time', 'tip', 'tongue', 'took', 'tool', 'top', 'tore', 'toss', 'touch', 'tough', 'tour', 'towel', 'town', 'tub', 'tube',
+                 'tight', 'time', 'tip', 'tongue', 'took', 'tool', 'top', 'tore', 'toss', 'touch', 'tough', 'tour', 'town', 'tub', 'tube',
                  'tune', 'turn', 'type', 'use', 'van', 'vet', 'vice', 'voice', 'vote', 'wade', 'wage', 'wait', 'wake', 'walk', 'wall', 'war',
                  'wash', 'watch', 'wear', 'web', 'week', 'weight', 'wet', 'whack', 'wheat', 'wheel', 'whim', 'whine', 'whip', 'white',
                  'whole', 'wick', 'wide', 'wife', 'win', 'wine', 'wing', 'wise', 'wish', 'woke', 'womb', 'wood', 'word', 'wore', 'work',
@@ -516,7 +516,7 @@ class WordToken(models.Model):
     FollSemPred = models.FloatField(blank=True,null=True)
     NumFormants = models.DecimalField('Number of formants',max_digits=4,decimal_places=1,blank=True,null=True)
     Ceiling = models.IntegerField(blank=True,null=True)
-    Output = PickledObjectField()
+    Output = PickledObjectField(null=True)
 
     objects = WTManager()
 
@@ -1084,11 +1084,17 @@ class WordToken(models.Model):
             elif form['measure'] == 'D':
                 outline['Dispersion'] = 'NA'
         to_out = [{k:outline[k] for k in outline if k in wanted_fields}]
-        if outline.keys() != self.Output.keys():
+        if self.Output is None or outline.keys() != self.Output.keys():
             self.Output = outline
             self.save()
         return to_out
 
+    def remove_field_from_output(self,f):
+        if f in self.Output:
+            self.Output = {x: self.Output[x] for x in self.Output if x != f}
+            self.save()
+
+
 #class SynSemCase(models.Model):
     #verb = models.ForeignKey(WordToken)
     #checked = models.NullBooleanField()
